@@ -22,10 +22,12 @@
 
 #if BTRFS_FLAT_INCLUDES
 #include "kerncompat.h"
-#include "extent-cache.h"
-#include "list.h"
+#include "kernel-shared/ctree.h"
+#include "common/extent-cache.h"
+#include "kernel-lib/list.h"
 #else
 #include <btrfs/kerncompat.h>
+#include <btrfs/ctree.h>
 #include <btrfs/extent-cache.h>
 #include <btrfs/list.h>
 #endif /* BTRFS_FLAT_INCLUDES */
@@ -111,7 +113,7 @@ struct device_extent_record {
 	u8  type;
 	u64 offset;
 
-	u64 chunk_objecteid;
+	u64 chunk_objectid;
 	u64 chunk_offset;
 	u64 length;
 };
@@ -140,6 +142,23 @@ static inline unsigned long btrfs_chunk_record_size(int num_stripes)
 }
 void free_chunk_cache_tree(struct cache_tree *chunk_cache);
 
+/*
+ * Function to check validation for num_stripes, or it can call
+ * float point error for 0 division
+ * return < 0 for invalid combination
+ * return 0 for valid combination
+ */
+static inline int check_num_stripes(u64 type, int num_stripes)
+{
+	if (num_stripes == 0)
+		return -1;
+	if (type & BTRFS_BLOCK_GROUP_RAID5 && num_stripes <= 1)
+		return -1;
+	if (type & BTRFS_BLOCK_GROUP_RAID6 && num_stripes <= 2)
+		return -1;
+	return 0;
+}
+
 u64 calc_stripe_length(u64 type, u64 length, int num_stripes);
 /* For block group tree */
 static inline void block_group_tree_init(struct block_group_tree *tree)
